## Get object from `AnnData`: `get`

```{eval-rst}
.. module:: scanpy.get
```

```{eval-rst}
.. currentmodule:: scanpy
```

The module `sc.get` provides convenience functions for getting values back in
useful formats.

```{eval-rst}
.. autosummary::
   :nosignatures:
   :toctree: ../generated/

   get.obs_df
   get.var_df
   get.rank_genes_groups_df
   get.aggregate

```
